.. FSC documentation master file, created by
   sphinx-quickstart on Mon Aug 22 13:43:37 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FusionSC's documentation!
====================================

What is FusionSC?
-----------------

Started as an effort to automate my personal workflow, FusionSC is a library intended to conveniently expose common
operations required when analyzing the structure of magnetic confinement fusion devices, including the structure of
the magnetic field as well as the machine geometry. 

For what is intended to be included in the near future, check out the roadmap.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   installation
   setup
   license
   architecture
   roadmap
   
   howto/index
   
   reference



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
